\name{rpudlTrain}
\alias{rpudlTrain}
\concept{deep learning}

\title{
RPUDL Model Training 
}

\description{
Optimizes a \code{RPUDL} deep learning model with training data.
}

\details{
The optimization training process supports the following algorithms:
\itemize{ 
  \item{Stochastic Gradient Descent}{}
  \item{RMSProp}{}
  \item{AdaGrad}{}
  \item{Adam}{}
}}

\usage{
rpudlTrain(
    model,
    learning.rate = 0,
    batch.size = 128,
    iterations = 128,
    display = 100,
    top.n = 1,
    seed = 0,
    ...,
    log.level = 1
    )
}

\arguments{
  \item{model}{a \code{rpudl} model object to be trained}
  \item{learning.rate}{manual override of the learning rate, ignored if zero or negative}
  \item{batch.size}{the size of a data batch for each training iteration}
  \item{iterations}{maximum number of training iterations}
  \item{display}{a logical to display training progress}
  \item{top.n}{a classification predict is considered an error if its top n results are all incorrect}
  \item{seed}{seed of random number generation}
  \item{\dots}{further arguments to be passed to or from methods}
  \item{log.level}{level of the method output (0 = silent, 
        1 = basic output, 2 = detailed output)} 
}

\value{
  A new \code{rpudl} object with trained parameters.
}

\author{
  Chi Yau\cr
  \email{chi.yau@r-tutor.com}
}

\seealso{
  rpudl,\cr
  rpudlPretrain,\cr
  predict.rpudl
}

\examples{
\dontrun{
# create data source
ds <- rpudlCreateDataSource(
        data.format="lmdb",
        data.dir="data/mnist",
        train.data="mnist-official-data_train_lmdb",
        test.data="mnist-official-data_test_lmdb",
        data.shape=c(28, 28)
)

# create model
model <- rpudl(
        "mnist_mpl_lenet.prototxt",
        data.source=ds
)   

# train model
model <- rpudlTrain(model, batch=100, iter=1000)
}}

\keyword{misc}


